function [xs1_sav,xs2_sav]=lpc_vary_p(xin,fs,ss,Lm,pinit,pdelta,iwin_LPC,iwin_STFT,lpcms,nfft)
%
% Program to illustrate the effects of changing lpc analysis order, p, on the
% resulting spectral match to the original speech signal spectrum
%
%  read in speech file, choose section of speech and solve for the set of
%  lpc coefficients using any lpc solution method, including:
%   - autocorrelation method,  
%   - covariance method, 
%   - lattice method
%  for a range of values of lpc frame size, Lm
%
%  plot the STFT log magnitude spectrum and overlay it with the lpc log
%  magnitude spectra for a range of values of p
%
% Inputs:
%   xin: input speech array
%   fs: sampling rate of speech
%   ss: starting sample in file
%   Lm: analysis frame length in msec
%   pinit: initial lpc system order
%   pdelta: change in lpc system order for each iteration
%   iwin_LPC: LPC analysis window type (1:Hamming, 2:Rectangular)
%   iwin_STFT: STFT analysis window type (1:Hamming, 2:Rectangular)
%   lpcms: lpc analysis method (ac:autocorrelation, co:covariance, la:lattice)
%   nfft: fft size
%
% Outputs:
%   xs1_sav: cell array with log magnitude STFT
%   xs2_sav: cell array with log magnitude lpc analyses for different
%   values of p

% loop on 5 values of p (pinit, pinit+pdelta, pinit+2*pdelta, pinit+3*pdelta,
% pinit+4*pdelta)
    ploop=5;
    
% loop on values of L
    for iloop=1:ploop
% convert frame length from msec to samples
        L=round(Lm*fs/1000);
        p=(iloop-1)*pdelta+pinit;

% define windows for STFT analysis
    if (iwin_STFT == 1)
        window_STFT=hamming(L)';
        U_STFT=sum(window_STFT.^2);
    elseif (iwin_STFT == 2)
        window_STFT=ones(1,L);
        U_STFT=L;
    end
    
% window for LPC analysis
    if (iwin_LPC == 1)
        window_LPC=hamming(L)';
        U_LPC=sum(window_LPC.^2)';
    elseif (iwin_LPC >= 2)
        window_LPC=ones(1,L);
        U_LPC=L;
    end
    Ulog_STFT=10*log10(U_STFT);
    Ulog_LPC=10*log10(U_LPC);
    
% form windowed sequence and compute its log spectrum
    xa=xin(ss:ss+L-1).*window_STFT';
    xs1=20*log10(abs(fft(xa,nfft)))-Ulog_STFT;
    xs1_sav{iloop}=xs1;
    
% extend windowed sequence for covariance and lattice methods
    xe=xin(ss:ss+L-1+p);
    
% process x by one of the three lpc analysis methods
    if (lpcms == 'ac')
        [R,E,k,alpha,G]=durbin(xa,L,p,iwin_LPC);
        den=[1 -alpha(1:p,p)'];
        xs2=20*log10(G)-20*log10(abs(fft(den,nfft)))-Ulog_LPC;
    elseif (lpcms == 'co')
        [phim,phiv,EC,alphac,GC]=cholesky(xe,L,p);
        denc=[1 -alphac'];
        xs2=20*log10(GC)-20*log10(abs(fft(denc,nfft)))-Ulog_LPC;
    elseif (lpcms == 'la')
        [EL,alphal,GL,k]=lattice(xe,L,p);
        alphalat=alphal(:,p);
        denl=[1 -alphalat'];
        xs2=20*log10(GL)-20*log10(abs(fft(denl,nfft)))-Ulog_LPC;
    end
    xs2_sav{iloop}=xs2;
    end
end

